bird: Plot a Colour Palette as a Bird

View source: R/ltc_functions.R

birdR Documentation

Plot a Colour Palette as a Bird

Description

Visualizes a selected colour palette in the form of a bird drawing. Requires at least 5 colors in the palette.

Usage

bird(chrom)

Arguments

chrom

An ltc palette object

Value

A ggplot2 object showing a bird drawing using the selected colours.

Examples


# Create a bird visualization
pal <- ltc(paloma)
bird(pal)


ltc documentation built on Jan. 16, 2026, 5:15 p.m.

Related to bird in ltc...