print.ltc: Print Method for ltc Objects

View source: R/ltc_functions.R

print.ltcR Documentation

Print Method for ltc Objects

Description

Custom print method that displays the palette name followed by hex color codes with actual colors visible in the console.

Usage

## S3 method for class 'ltc'
print(x, ...)

Arguments

x

An ltc palette object

...

Additional arguments (currently unused)

Value

Invisibly returns the palette object


ltc documentation built on Jan. 16, 2026, 5:15 p.m.

Related to print.ltc in ltc...