View source: R/ltc_functions.R
| bird | R Documentation |
Visualizes a selected colour palette in the form of a bird drawing. Requires at least 5 colors in the palette.
bird(chrom)
chrom |
An ltc palette object |
A ggplot2 object showing a bird drawing using the selected colours.
# Create a bird visualization
pal <- ltc(paloma)
bird(pal)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.