custom_adjust_ltc: Create Custom Palette with Individual Color Adjustments

View source: R/adjust_palette.R

custom_adjust_ltcR Documentation

Create Custom Palette with Individual Color Adjustments

Description

Apply different lightness adjustments to each color in a palette.

Usage

custom_adjust_ltc(palette_name, adjustments)

Arguments

palette_name

Character or unquoted name. Name of the ltc palette.

adjustments

Numeric vector. Lightness adjustments for each color (-100 to 100). Length must match the palette length.

Value

A vector of adjusted hex color codes with class "ltc"

Examples


# Different adjustment for each color
custom_adjust_ltc(remains, c(-30, 0, 40, 0))

# Create gradient effect
custom_adjust_ltc("maya", c(-40, -20, 0, 20, 40))


ltc documentation built on Jan. 16, 2026, 5:15 p.m.

Related to custom_adjust_ltc in ltc...