View source: R/adjust_palette.R
| custom_adjust_ltc | R Documentation |
Apply different lightness adjustments to each color in a palette.
custom_adjust_ltc(palette_name, adjustments)
palette_name |
Character or unquoted name. Name of the ltc palette. |
adjustments |
Numeric vector. Lightness adjustments for each color (-100 to 100). Length must match the palette length. |
A vector of adjusted hex color codes with class "ltc"
# Different adjustment for each color
custom_adjust_ltc(remains, c(-30, 0, 40, 0))
# Create gradient effect
custom_adjust_ltc("maya", c(-40, -20, 0, 20, 40))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.