View source: R/ltc_functions.R
| ltc | R Documentation |
A list containing predefined colour palettes with artistic backstories.
This function provides the desired colour palette by name. You can call it with or without quotes: ltc(paloma) or ltc("paloma")
palettes
ltc(name, n, type = c("discrete", "continuous"))
name |
Character or unquoted name. The name of the desired palette. |
n |
Integer. The number of colors you want from the palette. If omitted, it uses all colors from the palette. |
type |
The type of palette. Either "discrete" or "continuous". |
An object of class list of length 31.
ltc: A Collection of Art-inspired Colour Palettes
This package provides a collection of color palettes inspired by art, nature, and personal preferences. Each palette has a backstory, providing context and meaning to the colors.
A vector of hex color codes with class "ltc"
# Load a palette (with or without quotes)
ltc(paloma)
ltc("maya")
# Select first 3 colors
ltc(maya, n = 3)
# Generate continuous palette
ltc(remains, n = 10, type = "continuous")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.